summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoParagDia.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
commitc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (patch)
tree1ee1912ac4bb966475f0db0f2a78678661b4b4a5 /lib/kotext/KoParagDia.h
parent94844816550ad672ccfcdc25659c625546239998 (diff)
downloadkoffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.tar.gz
koffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 94844816550ad672ccfcdc25659c625546239998.
Diffstat (limited to 'lib/kotext/KoParagDia.h')
-rw-r--r--lib/kotext/KoParagDia.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/kotext/KoParagDia.h b/lib/kotext/KoParagDia.h
index 2f3cc751..c4bbed92 100644
--- a/lib/kotext/KoParagDia.h
+++ b/lib/kotext/KoParagDia.h
@@ -24,7 +24,7 @@
#include <kdialogbase.h>
#include <tqstringlist.h>
#include <tqptrlist.h>
-#include <stylesheet.h>
+#include <tqstylesheet.h>
#include <KoRuler.h>
#include <KoUnit.h>
#include <KoUnitWidgets.h>
@@ -95,7 +95,7 @@ public:
/** return the (i18n-ed) name of the tab */
virtual TQString tabName() = 0;
- // Return the part of the paraglayout that this widget cares about
+ // Return the part of the paragtqlayout that this widget cares about
int flag() const { return m_flag; }
private:
@@ -147,7 +147,7 @@ private:
};
/**
* The widget for editing paragraph alignment (tab 2)
*/
class KOTEXT_EXPORT KoParagAlignWidget : public KoParagLayoutWidget
{
@@ -369,7 +369,7 @@ protected slots:
void restartChanged(bool b) {m_counter.setRestartCounter(b); }
void depthChanged(int i) {m_counter.setDepth(i); updatePreview();}
void displayLevelsChanged(int i) {m_counter.setDisplayLevels(i); updatePreview();}
- void alignmentChanged(int i) {m_counter.setAlignment(i); updatePreview();}
+ void alignmentChanged(int i) {m_counter.tqsetAlignment(i); updatePreview();}
void slotChangeCustomBullet( const TQString & f, TQChar c);
void styleChanged (KoParagCounter::Style st );
@@ -549,7 +549,7 @@ public:
TQColor backgroundColor() const { return m_decorationsWidget->backgroundColor(); }
// Support for "what has changed?"
- bool isAlignChanged() const {return oldLayout.alignment!=align();}
+ bool isAlignChanged() const {return oldLayout.tqalignment!=align();}
bool isLineSpacingChanged() const {
return (oldLayout.lineSpacingValue() !=lineSpacing() ||
oldLayout.lineSpacingType != lineSpacingType());
@@ -147,7 +147,7 @@ private:
};
/**
- * The widget for editing paragraph alignment (tab 2)
+ * The widget for editing paragraph tqalignment (tab 2)
*/
class KOTEXT_EXPORT KoParagAlignWidget : public KoParagLayoutWidget